@@ -7,7 +7,10 @@
 #' @inheritParams can_verify_roundtrip
 #' @keywords internal
 communicate_warning <- function(changed, transformers) {
-  if (any(changed, na.rm = TRUE) && !can_verify_roundtrip(transformers)) {
+  if (any(changed, na.rm = TRUE) && 
+    !can_verify_roundtrip(transformers) &&
+    !getOption("styler.quiet", FALSE)
+  ) {
     cat("Please review the changes carefully!", fill = TRUE)
   }
 }
@@ -19,12 +22,14 @@ communicate_warning <- function(changed, transformers) {
 #' @param ruler_width Integer used to determine the width of the ruler.
 #' @keywords internal
 communicate_summary <- function(changed, ruler_width) {
-  cli::cat_rule(width = max(40, ruler_width))
-  cat("Status\tCount\tLegend \n")
-  cli::cat_bullet("\t", sum(!changed, na.rm = TRUE), "\tFile unchanged.", bullet = "tick")
-  cli::cat_bullet("\t", sum(changed, na.rm = TRUE), "\tFile changed.", bullet = "info")
-  cli::cat_bullet(bullet = "cross", "\t", sum(is.na(changed)), "\tStyling threw an error.")
-  cli::cat_rule(width = max(40, ruler_width))
+  if (!getOption("styler.quiet", FALSE)) {
+    cli::cat_rule(width = max(40, ruler_width))
+    cat("Status\tCount\tLegend \n")
+    cli::cat_bullet("\t", sum(!changed, na.rm = TRUE), "\tFile unchanged.", bullet = "tick")
+    cli::cat_bullet("\t", sum(changed, na.rm = TRUE), "\tFile changed.", bullet = "info")
+    cli::cat_bullet(bullet = "cross", "\t", sum(is.na(changed)), "\tStyling threw an error.")
+    cli::cat_rule(width = max(40, ruler_width))
+  }
 }
 
 #' @importFrom rlang abort
